@@ -1,5 +1,5 @@
 /*
-Copyright (C) 1997-2012 Erwin Waterlander
+Copyright (C) 1997-2018 Erwin Waterlander
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -55,7 +55,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #      define GO_FILE "/wcdgo.ps1"
 #    elif defined(_WIN32)
 #      define GO_FILE "/wcdgo.bat"
-#    elif defined(__OS2__)
+#    elif (defined(__OS2__) && !defined(WCD_OS2BASH))
 #      define GO_FILE "/wcdgo.cmd"
 #    else
 #      define GO_FILE "/wcd.go"
@@ -146,12 +146,12 @@ FILE *wcd_fopen(const char *filename, const char *m, int quiet);
 FILE *wcd_fopen_bom(const char *filename, const char *m, int quiet, int *bomtype);
 int wcd_fprintf(FILE *stream, const char *format, ...);
 void wcd_fclose(FILE *fp, const char *filename, const char *m, const char *functionname);
-void finddirs(char *dir, size_t *offset, FILE *outfile, int *use_HOME, nameset exclude, int quiet);
 int read_treefile(char *filename, nameset bd, int silent);
 void rmDirFromList(char *string, nameset n);
 void writeList(char *filename, nameset n, int bomtype);
 void cleanTreeFile(char *filename, char *dir);
 void create_dir_for_file(const char *f);
+void trimPath(char* path, size_t n);
 
 char *removeBackSlash(char *string);
 void addCurPathToFile(char *filename, int *use_HOME, int parents);
@@ -172,14 +172,17 @@ void print_license(void);
 int  wcd_get_int(void);
 int wcd_getline(char s[], int lim, FILE* infile, const char* file_name, const int* line_nr);
 int read_treefile_line (char line[], FILE* infile, const char* file_name, const int* line_nr, int bomtype);
-int wcd_exit(nameset pm, nameset wm, nameset ef, nameset bd, nameset nfs, WcdStack ws, nameset excl);
+int wcd_exit(nameset pm, nameset wm, nameset ef, nameset bd, nameset nfs, WcdStack ws, nameset excl, nameset scan_dirs, nameset filter);
 char *getCurPath(char *buffer, size_t size, int *use_HOME);
+size_t pathInNameset (text path, nameset set);
+#ifdef _WCD_DOSFS
+void rmDriveLetter(char path[], int *use_HOME);
+#endif
 
 #ifdef WCD_DOSBASH
 	void empty_wcdgo(char *go_file, int changedrive, char *drive, int use_GoScript, int verbose);
 #else
 	void empty_wcdgo(char *go_file, int use_GoScript, int verbose);
 #endif
-int SpecialDir(const char *path);
 
 #endif
